==> 2.0.63.tar.gz: lib/spectus_in_app_purchase.dart <==

import 'dart:async';
import 'dart:ffi';

import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

class SpectusInAppPurchase {
  static const MethodChannel _channel =
      const MethodChannel('spectus_in_app_purchase');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<String> startInAppPurchaseWith({String productID}) async
  {
    final String transactionID = await _channel.invokeMethod('startInAppPurchaseWith',
        {
          "productID":productID
        }
    );

    if (transactionID == null) {
      return "NA";
    } else {
      return transactionID;
    }
  }

  static Future<List<Map<String, String>>> getSKUProductListWith({String productID}) async
  {
    final String productsInfo = await _channel.invokeMethod('getSKUProductListWith',
        {
          "productID":productID
        }
    );
    print("DART => Product List count");

    var info = split(productsInfo, '&&');
    var productObject = {
      "amount" : info[0],
      "currency_code" : info[1],
      "title" : info[2],
      "description" : info[3]
    }; //SEQUENCE: Price && Currency Code && Title && Description && SKU (product_id)

    var array = [productObject];

    return array;
  }

  static Future<String> startRestorePurchase() async
  {
    final String transactionID = await _channel.invokeMethod('startRestorePurchase');
    if (transactionID == null) {
      return "NA";
    } else {
      return transactionID;
    }
  }
}

List<String> split(String string, String separator, {int max = 0}) {
  var result = List<String>();

  if (separator.isEmpty) {
    result.add(string);
    return result;
  }

  while (true) {
    var index = string.indexOf(separator, 0);
    if (index == -1 || (max > 0 && result.length >= max)) {
      result.add(string);
      break;
    }

    result.add(string.substring(0, index));
    string = string.substring(index + separator.length);
  }

  return result;
}

==> 3.0.0.tar.gz: lib/spectus_in_app_purchase.dart <==

import 'dart:async';
import 'dart:ffi';

import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

class SpectusInAppPurchase {
  static const MethodChannel _channel =
      const MethodChannel('spectus_in_app_purchase');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<String> startInAppPurchaseWith({String productID}) async
  {
    final String transactionID = await _channel.invokeMethod('startInAppPurchaseWith',
        {
          "productID":productID
        }
    );

    if (transactionID == null) {
      return "NA";
    } else {
      return transactionID;
    }
  }

  static Future<List<Map<String, String>>> getSKUProductListWith({List<String> productIDs}) async
  {
    final String productsInfo = await _channel.invokeMethod('getSKUProductListWith',
        {
          "productIDs":productIDs
        }
    );
    print("DART => Product List count");

    var array = [];
    var mainArray = split(productsInfo, '&^&');
    mainArray.forEach((singleItem) {
      var info = split(singleItem, '&&');
      var productObject = {
        "amount" : info[0],
        "currency_code" : info[1],
        "title" : info[2],
        "description" : info[3],
        "product_id" : info[4]
      }; //SEQUENCE: Price && Currency Code && Title && Description && SKU (product_id)
      array.add(productObject)
    });
    return array;
  }

  static Future<String> startRestorePurchase() async
  {
    final String transactionID = await _channel.invokeMethod('startRestorePurchase');
    if (transactionID == null) {
      return "NA";
    } else {
      return transactionID;
    }
  }
}

List<String> split(String string, String separator, {int max = 0}) {
  var result = List<String>();

  if (separator.isEmpty) {
    result.add(string);
    return result;
  }

  while (true) {
    var index = string.indexOf(separator, 0);
    if (index == -1 || (max > 0 && result.length >= max)) {
      result.add(string);
      break;
    }

    result.add(string.substring(0, index));
    string = string.substring(index + separator.length);
  }

  return result;
}
